@@ -1,7 +1,6 @@
 #[cfg(test)]
 mod change_cipher_spec_test;
 
-use anyhow::Result;
 use byteorder::{ReadBytesExt, WriteBytesExt};
 use std::io::{Read, Write};
 
@@ -34,7 +33,7 @@ impl ChangeCipherSpec {
     pub fn unmarshal<R: Read>(reader: &mut R) -> Result<Self> {
         let data = reader.read_u8()?;
         if data != 0x01 {
-            return Err(Error::ErrInvalidCipherSpec.into());
+            return Err(Error::ErrInvalidCipherSpec);
         }
 
         Ok(ChangeCipherSpec {})
