@@ -94,7 +94,7 @@ fn psk_callback_server(hint: &[u8]) -> Result<Vec<u8>> {
 }
 
 fn psk_callback_hint_fail(_hint: &[u8]) -> Result<Vec<u8>> {
-    Err(Error::new(ERR_PSK_REJECTED.to_owned()).into())
+    Err(Error::Other(ERR_PSK_REJECTED.to_owned()))
 }
 
 async fn create_test_client(
@@ -467,10 +467,7 @@ async fn test_export_keying_material() -> Result<()> {
 
     c.set_local_epoch(1);
     let state = c.connection_state().await;
-    if let Err(err) = state
-        .export_keying_material(&export_label, &[0x00], 0)
-        .await
-    {
+    if let Err(err) = state.export_keying_material(export_label, &[0x00], 0).await {
         assert!(
             err.to_string()
                 .contains(&Error::ErrContextUnsupported.to_string()),
@@ -498,7 +495,7 @@ async fn test_export_keying_material() -> Result<()> {
     }
 
     let state = c.connection_state().await;
-    let keying_material = state.export_keying_material(&export_label, &[], 10).await?;
+    let keying_material = state.export_keying_material(export_label, &[], 10).await?;
     assert_eq!(
         &keying_material, &expected_server_key,
         "ExportKeyingMaterial client export: expected ({:?}) actual ({:?})",
@@ -507,7 +504,7 @@ async fn test_export_keying_material() -> Result<()> {
 
     c.state.is_client = true;
     let state = c.connection_state().await;
-    let keying_material = state.export_keying_material(&export_label, &[], 10).await?;
+    let keying_material = state.export_keying_material(export_label, &[], 10).await?;
     assert_eq!(
         &keying_material, &expected_client_key,
         "ExportKeyingMaterial client export: expected ({:?}) actual ({:?})",
@@ -859,15 +856,13 @@ async fn test_srtp_configuration() -> Result<()> {
                 } else {
                     assert!(false, "{} expected error, but got ok", name);
                 }
+            } else if let Ok(client) = result {
+                let actual_client_srtp = client.selected_srtpprotection_profile();
+                assert_eq!(actual_client_srtp, expected_profile,
+                           "test_srtp_configuration: Client SRTPProtectionProfile Mismatch '{}': expected({:?}) actual({:?})",
+                           name, expected_profile, actual_client_srtp);
             } else {
-                if let Ok(client) = result {
-                    let actual_client_srtp = client.selected_srtpprotection_profile();
-                    assert_eq!(actual_client_srtp, expected_profile,
-                               "test_srtp_configuration: Client SRTPProtectionProfile Mismatch '{}': expected({:?}) actual({:?})",
-                               name, expected_profile, actual_client_srtp);
-                } else {
-                    assert!(false, "{} expected no error", name);
-                }
+                assert!(false, "{} expected no error", name);
             }
         } else {
             assert!(false, "{} expected client, but got none", name);
@@ -900,13 +895,13 @@ async fn test_client_certificate() -> Result<()> {
     let mut srv_ca_pool = rustls::RootCertStore::empty();
     srv_ca_pool
         .add(&srv_cert.certificate[0])
-        .or_else(|_err| Err(Error::new("add srv_cert error".to_owned())))?;
+        .map_err(|_err| Error::Other("add srv_cert error".to_owned()))?;
 
     let cert = Certificate::generate_self_signed(vec!["localhost".to_owned()])?;
     let mut ca_pool = rustls::RootCertStore::empty();
     ca_pool
         .add(&cert.certificate[0])
-        .or_else(|_err| Err(Error::new("add cert error".to_owned())))?;
+        .map_err(|_err| Error::Other("add cert error".to_owned()))?;
 
     let tests = vec![
         (
@@ -1342,20 +1337,20 @@ async fn test_extended_master_secret() -> Result<()> {
 
 fn fn_not_expected_chain(_cert: &[Vec<u8>], chain: &[rustls::Certificate]) -> Result<()> {
     if !chain.is_empty() {
-        return Err(Error::new(ERR_NOT_EXPECTED_CHAIN.to_owned()).into());
+        return Err(Error::Other(ERR_NOT_EXPECTED_CHAIN.to_owned()));
     }
     Ok(())
 }
 
 fn fn_expected_chain(_cert: &[Vec<u8>], chain: &[rustls::Certificate]) -> Result<()> {
     if chain.is_empty() {
-        return Err(Error::new(ERR_EXPECTED_CHAIN.to_owned()).into());
+        return Err(Error::Other(ERR_EXPECTED_CHAIN.to_owned()));
     }
     Ok(())
 }
 
 fn fn_wrong_cert(_cert: &[Vec<u8>], _chain: &[rustls::Certificate]) -> Result<()> {
-    Err(Error::new(ERR_WRONG_CERT.to_owned()).into())
+    Err(Error::Other(ERR_WRONG_CERT.to_owned()))
 }
 
 #[tokio::test]
@@ -1380,7 +1375,7 @@ async fn test_server_certificate() -> Result<()> {
     let mut ca_pool = rustls::RootCertStore::empty();
     ca_pool
         .add(&cert.certificate[0])
-        .or_else(|_err| Err(Error::new("add cert error".to_owned())))?;
+        .map_err(|_err| Error::Other("add cert error".to_owned()))?;
 
     let tests = vec![
         (
