@@ -2,7 +2,7 @@ use super::flight2::*;
 use super::*;
 use crate::config::*;
 use crate::conn::*;
-use crate::error::*;
+use crate::error::Error;
 use crate::extension::*;
 use crate::handshake::*;
 use crate::record_layer::record_layer_header::*;
@@ -30,7 +30,7 @@ impl Flight for Flight0 {
         state: &mut State,
         cache: &HandshakeCache,
         cfg: &HandshakeConfig,
-    ) -> Result<Box<dyn Flight + Send + Sync>, (Option<Alert>, Option<anyhow::Error>)> {
+    ) -> Result<Box<dyn Flight + Send + Sync>, (Option<Alert>, Option<Error>)> {
         let (seq, msgs) = match cache
             .full_pull_map(
                 0,
@@ -70,7 +70,7 @@ impl Flight for Flight0 {
                         alert_level: AlertLevel::Fatal,
                         alert_description: AlertDescription::ProtocolVersion,
                     }),
-                    Some(Error::ErrUnsupportedProtocolVersion.into()),
+                    Some(Error::ErrUnsupportedProtocolVersion),
                 ));
             }
 
@@ -94,7 +94,7 @@ impl Flight for Flight0 {
                         alert_level: AlertLevel::Fatal,
                         alert_description: AlertDescription::InsufficientSecurity,
                     }),
-                    Some(Error::ErrCipherSuiteNoIntersection.into()),
+                    Some(Error::ErrCipherSuiteNoIntersection),
                 ));
             }
 
@@ -107,7 +107,7 @@ impl Flight for Flight0 {
                                     alert_level: AlertLevel::Fatal,
                                     alert_description: AlertDescription::InsufficientSecurity,
                                 }),
-                                Some(Error::ErrNoSupportedEllipticCurves.into()),
+                                Some(Error::ErrNoSupportedEllipticCurves),
                             ));
                         }
                         state.named_curve = e.elliptic_curves[0];
@@ -124,7 +124,7 @@ impl Flight for Flight0 {
                                     alert_level: AlertLevel::Fatal,
                                     alert_description: AlertDescription::InsufficientSecurity,
                                 }),
-                                Some(Error::ErrServerNoMatchingSrtpProfile.into()),
+                                Some(Error::ErrServerNoMatchingSrtpProfile),
                             ));
                         }
                     }
@@ -148,7 +148,7 @@ impl Flight for Flight0 {
                         alert_level: AlertLevel::Fatal,
                         alert_description: AlertDescription::InsufficientSecurity,
                     }),
-                    Some(Error::ErrServerRequiredButNoClientEms.into()),
+                    Some(Error::ErrServerRequiredButNoClientEms),
                 ));
             }
 
@@ -184,7 +184,7 @@ impl Flight for Flight0 {
         state: &mut State,
         _cache: &HandshakeCache,
         _cfg: &HandshakeConfig,
-    ) -> Result<Vec<Packet>, (Option<Alert>, Option<anyhow::Error>)> {
+    ) -> Result<Vec<Packet>, (Option<Alert>, Option<Error>)> {
         // Initialize
         state.cookie = vec![0; COOKIE_LENGTH];
         rand::thread_rng().fill(state.cookie.as_mut_slice());
