@@ -4,7 +4,7 @@ use std::io::{BufReader, BufWriter};
 use std::time::{Duration, SystemTime};
 
 #[test]
-fn test_handshake_message_server_hello() -> Result<(), Error> {
+fn test_handshake_message_server_hello() -> Result<()> {
     let raw_server_hello = vec![
         0xfe, 0xfd, 0x21, 0x63, 0x32, 0x21, 0x81, 0x0e, 0x98, 0x6c, 0x85, 0x3d, 0xa4, 0x39, 0xaf,
         0x5f, 0xd6, 0x5c, 0xcc, 0x20, 0x7f, 0x7c, 0x78, 0xf1, 0x5f, 0x7e, 0x1c, 0xb7, 0xa1, 0x1e,
