@@ -1,10 +1,10 @@
 use crate::config::*;
 use crate::conn::DTLSConn;
 use crate::content::ContentType;
+use crate::error::Result;
 use crate::record_layer::record_layer_header::RecordLayerHeader;
 use crate::record_layer::unpack_datagram;
 
-use anyhow::Result;
 use async_trait::async_trait;
 use std::future::Future;
 use std::io::BufReader;
@@ -63,27 +63,31 @@ impl DTLSListener {
     }
 }
 
+type UtilResult<T> = std::result::Result<T, util::Error>;
+
 #[async_trait]
 impl Listener for DTLSListener {
     /// Accept waits for and returns the next connection to the listener.
     /// You have to either close or read on all connection that are created.
     /// Connection handshake will timeout using ConnectContextMaker in the Config.
     /// If you want to specify the timeout duration, set ConnectContextMaker.
-    async fn accept(&self) -> Result<(Arc<dyn Conn + Send + Sync>, SocketAddr)> {
+    async fn accept(&self) -> UtilResult<(Arc<dyn Conn + Send + Sync>, SocketAddr)> {
         let (conn, raddr) = self.parent.accept().await?;
-        let dtls_conn = DTLSConn::new(conn, self.config.clone(), false, None).await?;
+        let dtls_conn = DTLSConn::new(conn, self.config.clone(), false, None)
+            .await
+            .map_err(util::Error::from_std)?;
         Ok((Arc::new(dtls_conn), raddr))
     }
 
     /// Close closes the listener.
     /// Any blocked Accept operations will be unblocked and return errors.
     /// Already Accepted connections are not closed.
-    async fn close(&self) -> Result<()> {
+    async fn close(&self) -> UtilResult<()> {
         self.parent.close().await
     }
 
     /// Addr returns the listener's network address.
-    async fn addr(&self) -> Result<SocketAddr> {
+    async fn addr(&self) -> UtilResult<SocketAddr> {
         self.parent.addr().await
     }
 }
